==> openshift-model-console-5.11.2-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginBuilder.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsolePluginBuilder extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginFluentImpl<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1alpha1.ConsolePlugin,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginBuilder>{
  public ConsolePluginBuilder() {
    this(false);
  }
  public ConsolePluginBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsolePlugin(), validationEnabled);
  }
  public ConsolePluginBuilder(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsolePluginBuilder(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsolePlugin(), validationEnabled);
  }
  public ConsolePluginBuilder(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginFluent<?> fluent,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePlugin instance) {
    this(fluent, instance, false);
  }
  public ConsolePluginBuilder(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginFluent<?> fluent,io.fabric8.openshift.api.model.console.v1alpha1.ConsolePlugin instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsolePluginBuilder(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePlugin instance) {
    this(instance,false);
  }
  public ConsolePluginBuilder(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePlugin instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1alpha1.ConsolePlugin build() {
    ConsolePlugin buildable = new ConsolePlugin(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsolePluginBuilder that = (ConsolePluginBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-6.4.0-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginBuilder.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsolePluginBuilder extends ConsolePluginFluentImpl<ConsolePluginBuilder> implements VisitableBuilder<ConsolePlugin,ConsolePluginBuilder>{
  public ConsolePluginBuilder() {
    this(false);
  }
  public ConsolePluginBuilder(Boolean validationEnabled) {
    this(new ConsolePlugin(), validationEnabled);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsolePlugin(), validationEnabled);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,ConsolePlugin instance) {
    this(fluent, instance, false);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,ConsolePlugin instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsolePluginBuilder(ConsolePlugin instance) {
    this(instance,false);
  }
  public ConsolePluginBuilder(ConsolePlugin instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ConsolePluginFluent<?> fluent;
  Boolean validationEnabled;
  public ConsolePlugin build() {
    ConsolePlugin buildable = new ConsolePlugin(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
